=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2007-09-13 01:54:49 +0000
+++ bzrlib/bzrdir.py	2007-09-14 14:45:55 +0000
@@ -245,6 +245,7 @@
         raise NotImplementedError(self.create_branch)
 
     def destroy_branch(self):
+        """Destroy the branch in this BzrDir"""
         raise NotImplementedError(self.destroy_branch)
 
     @staticmethod
@@ -898,7 +899,7 @@
         return self.open_branch()
 
     def destroy_branch(self):
-        """See BzrDir.destroy_workingtree."""
+        """See BzrDir.destroy_branch."""
         raise errors.UnsupportedOperation(self.destroy_branch, self)
 
     def create_repository(self, shared=False):

=== modified file 'bzrlib/reconfigure.py'
--- bzrlib/reconfigure.py	2007-09-14 14:13:14 +0000
+++ bzrlib/reconfigure.py	2007-09-14 14:45:55 +0000
@@ -55,6 +55,13 @@
 
     @staticmethod
     def to_branch(bzrdir):
+        """Return a Reconfiguration to convert this bzrdir into a branch
+
+        :param bzrdir: The bzrdir to reconfigure
+        :raise errors.AlreadyBranch: if bzrdir is already a branch
+        :raise errors.ReconfigurationNotSupported: if bzrdir does not contain
+            a branch or branch reference
+        """
         reconfiguration = Reconfigure(bzrdir)
         reconfiguration._plan_changes(want_tree=False, want_branch=True,
                                       want_bound=False)
@@ -64,6 +71,13 @@
 
     @staticmethod
     def to_tree(bzrdir):
+        """Return a Reconfiguration to convert this bzrdir into a tree
+
+        :param bzrdir: The bzrdir to reconfigure
+        :raise errors.AlreadyTree: if bzrdir is already a tree
+        :raise errors.ReconfigurationNotSupported: if bzrdir does not contain
+            a branch or branch reference
+        """
         reconfiguration = Reconfigure(bzrdir)
         reconfiguration._plan_changes(want_tree=True, want_branch=True,
                                       want_bound=False)
@@ -73,6 +87,14 @@
 
     @staticmethod
     def to_checkout(bzrdir, bound_location=None):
+        """Return a Reconfiguration to convert this bzrdir into a checkout
+
+        :param bzrdir: The bzrdir to reconfigure
+        :param bound_location: The location the checkout should be bound to.
+        :raise errors.AlreadyCheckout: if bzrdir is already a checkout
+        :raise errors.ReconfigurationNotSupported: if bzrdir does not contain
+            a branch or branch reference
+        """
         reconfiguration = Reconfigure(bzrdir, bound_location)
         reconfiguration._plan_changes(want_tree=True, want_branch=True,
                                       want_bound=True)
@@ -145,6 +167,15 @@
         raise errors.NoBindLocation(self.bzrdir)
 
     def apply(self, force=False):
+        """Apply the reconfiguration
+
+        :param force: If true, the reconfiguration is applied even if it will
+            destroy local changes.
+        :raise errors.UncommittedChanges: if the local tree is to be destroyed
+            but contains uncommitted changes.
+        :raise errors.NoBindLocation: if no bind location was specified and
+            none could be autodetected.
+        """
         if not force:
             self._check()
         if self._create_repository:

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2007-09-09 07:13:15 +0000
+++ bzrlib/remote.py	2007-09-14 14:45:55 +0000
@@ -90,6 +90,7 @@
         return RemoteBranch(self, self.find_repository(), real_branch)
 
     def destroy_branch(self):
+        """See BzrDir.destroy_branch"""
         self._ensure_real()
         self._real_bzrdir.destroy_branch()
 

